@@ -22,6 +22,7 @@
 
 #include <qpa/qplatformmenu.h>
 #include <qpa/qplatformsystemtrayicon.h>
+#include <QVariant>
 
 class KStatusNotifierItem;
 class SystemTrayMenuItem;
@@ -49,9 +50,16 @@ public:
     QPlatformMenuItem *createMenuItem() const override;
     QPlatformMenu *createSubMenu() const override;
 
-    QMenu *menu() const;
+    QMenu *menu();
 
 private:
+    void createMenu();
+
+    QString m_text;
+    QIcon m_icon;
+    QVariant m_enabled;
+    QVariant m_visible;
+    QVariant m_separatorsCollapsible;
     quintptr m_tag;
     QPointer<QMenu> m_menu;
     QList<SystemTrayMenuItem*> m_items;
