@@ -27,7 +27,7 @@ class KdePlatformThemePlugin : public QPlatformThemePlugin
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QPA.QPlatformThemeFactoryInterface.5.1" FILE "kdeplatformtheme.json")
 public:
-    KdePlatformThemePlugin(QObject *parent = 0)
+    KdePlatformThemePlugin(QObject *parent = nullptr)
         : QPlatformThemePlugin(parent) {}
 
     QPlatformTheme *create(const QString &key, const QStringList &paramList) override
